@@ -41,8 +41,6 @@ _wrap_vte_terminal_new(PyGObject *self, PyObject *args, PyObject *kwargs)
         PyErr_SetString(PyExc_RuntimeError, "could not create VteTerminal object");
         return -1;
     }
-    g_object_ref(self->obj);
-    gtk_object_sink(GTK_OBJECT(self->obj));
     pygobject_register_wrapper((PyObject *)self);
     return 0;
 }
@@ -120,7 +118,7 @@ _wrap_vte_terminal_fork_command(PyGObject * self, PyObject * args,
 
 	return PyInt_FromLong(pid);
 }
-#line 124 "vte.c"
+#line 122 "vte.c"
 
 
 static PyObject *
@@ -371,7 +369,7 @@ _wrap_vte_terminal_set_colors(PyGObject *self, PyObject *args, PyObject *kwargs)
     Py_INCREF(Py_None);
     return Py_None;
 }
-#line 375 "vte.c"
+#line 373 "vte.c"
 
 
 static PyObject *
@@ -767,8 +765,8 @@ _wrap_vte_terminal_get_text(PyGObject *self, PyObject *args, PyObject *kwargs)
 	    
 	    PyDict_SetItemString(py_char_attr, "underline", 
 		    PyInt_FromLong(cht->underline));
-	    PyDict_SetItemString(py_char_attr, "alternate", 
-		    PyInt_FromLong(cht->alternate));
+	    PyDict_SetItemString(py_char_attr, "strikethrough", 
+		    PyInt_FromLong(cht->strikethrough));
 
 	    PyTuple_SetItem(py_attrs, count, py_char_attr);
 	}
@@ -778,7 +776,7 @@ _wrap_vte_terminal_get_text(PyGObject *self, PyObject *args, PyObject *kwargs)
     	return Py_BuildValue("O", text);
     }
 }
-#line 782 "vte.c"
+#line 780 "vte.c"
 
 
 #line 213 "vte.override"
@@ -864,8 +862,8 @@ _wrap_vte_terminal_get_text_range(PyGObject *self, PyObject *args, PyObject *kwa
 	    
 	    PyDict_SetItemString(py_char_attr, "underline", 
 		    PyInt_FromLong(cht->underline));
-	    PyDict_SetItemString(py_char_attr, "alternate", 
-		    PyInt_FromLong(cht->alternate));
+	    PyDict_SetItemString(py_char_attr, "strikethrough", 
+		    PyInt_FromLong(cht->strikethrough));
 
 	    PyTuple_SetItem(py_attrs, count, py_char_attr);
 	}
@@ -875,7 +873,7 @@ _wrap_vte_terminal_get_text_range(PyGObject *self, PyObject *args, PyObject *kwa
     	return Py_BuildValue("O", text);
     }
 }
-#line 879 "vte.c"
+#line 877 "vte.c"
 
 
 static PyObject *
@@ -1214,6 +1212,6 @@ pyvte_register_classes(PyObject *d)
     }
 
 
-#line 1218 "vte.c"
+#line 1216 "vte.c"
     pygobject_register_class(d, "VteTerminal", VTE_TYPE_TERMINAL, &PyVteTerminal_Type, Py_BuildValue("(O)", &PyGtkWidget_Type));
 }
